@@ -1,5 +1,5 @@
 var Riot=Riot||{};
-"object"===typeof Riot&&function(){var j=window,l=document,c=j.localStorage,e=Riot.DDragon={mu:"http://ddragonqa.riotgames.com/realms/na.js",it:0,fixed:"fixed",langInterface:{ar:"ar_AR",bg:"bg_BG",cs:"cs_CZ",de:"de_DE",el:"el_GR",en:"en_US",es:"es_ES",fr:"fr_FR",hu:"hu_HU",it:"it_IT",ja:"ja_JP",ko:"ko_KR",nl:"nl_NL",pl:"pl_PL",pt:"pt_BR",ro:"ro_RO",ru:"ru_RU",th:"th_TH",tr:"tr_TR",vn:"vn_VN",zh:"zh_CN"},jsonp:function(a,b){var f=l.createElement("script");f.setAttribute("type","text/javascript");f.setAttribute("async",
+"object"===typeof Riot&&function(){var j=window,l=document,c=j.localStorage,e=Riot.DDragon={mu:"http://ddragonqa.riotgames.com/realms/na.js",it:0,fixed:"fixed",langInterface:{ar:"ar_AR",bg:"bg_BG",cs:"cs_CZ",de:"de_DE",el:"el_GR",en:"en_US",es:"es_ES",fr:"fr_FR",hu:"hu_HU",it:"it_IT",ja:"ja_JP",ko:"ko_KR",nl:"nl_NL",pl:"pl_PL",pt:"pt_BR",ro:"ro_RO",ru:"ru_RU",th:"th_TH",tr:"tr_TR",vi:"vi_VN",zh:"zh_CN"},jsonp:function(a,b){var f=l.createElement("script");f.setAttribute("type","text/javascript");f.setAttribute("async",
 "async");f.setAttribute("src",a);if("function"==typeof b)f.onload="object"===typeof j.onload&&"object"===typeof j.onreadystatechange?b:f.onreadystatechange=b;f&&l.body.appendChild(f)},xhr:{ready:!0,getHTTPObject:function(){var a=!1;if("undefined"!==typeof ActiveXObject)try{a=new ActiveXObject("Msxml2.XMLHTTP")}catch(b){try{a=new ActiveXObject("Microsoft.XMLHTTP")}catch(f){a=!1}}else if(j.XMLHttpRequest)try{a=new XMLHttpRequest}catch(d){a=!1}return a},load:function(a,b,f){if(e.xhr.ready){var d=this.init();
 if(d&&a){try{d.open("GET",a,!0)}catch(h){e.xhr.ready=!1;e.jsonp(a,f);return}d.onreadystatechange=function(){var h="";if(4===d.readyState&&e.xhr.ready)switch(d.status){case 200:case 304:if(d.responseText)h=d.responseText;b(h);break;default:e.xhr.ready=!1,e.jsonp(a,f)}};d.send(null)}}else e.jsonp(a,f)},init:function(){return this.getHTTPObject()}},app:[],addApp:function(a,b){e.app.push({app:b,ms:a||[]})},mps:{},amp:function(a,b){e.mps[a]?e.mps[a].push(b):e.mps[a]=[b]},addModelParser:function(a,b){e.amp(a,
 b)},ddf:"/js/dragonmagic.pure.js"};if("string"===typeof j.rg_force_manifest)e.mu=j.rg_force_manifest;if("boolean"==typeof j.rg_force_jsonp)e.xhr.ready=!j.rg_force_jsonp;"object"===typeof j.rg_force_manifest_object?e.m=j.rg_force_manifest_object:e.jsonp(e.mu,function(){if("object"===typeof e.m){var a=e,b;try{c.setItem("modernizr","modernizr"),c.removeItem("modernizr"),b=!0}catch(f){b=!1}a.ls=b;if("string"===typeof j.rg_force_language){if(-1===j.rg_force_language.indexOf("_"))j.rg_force_language=e.langInterface[j.rg_force_language];
